// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef PIMCOMMON_VERSION_H
#define PIMCOMMON_VERSION_H

#define PIMCOMMON_VERSION_STRING "6.6.90"
#define PIMCOMMON_VERSION_MAJOR 6
#define PIMCOMMON_VERSION_MINOR 6
#define PIMCOMMON_VERSION_PATCH 90
#define PIMCOMMON_VERSION ((6<<16)|(6<<8)|(90))

#endif
