// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef PIMCOMMONAKONADI_VERSION_H
#define PIMCOMMONAKONADI_VERSION_H

#define PIMCOMMONAKONADI_VERSION_STRING "6.6.90"
#define PIMCOMMONAKONADI_VERSION_MAJOR 6
#define PIMCOMMONAKONADI_VERSION_MINOR 6
#define PIMCOMMONAKONADI_VERSION_PATCH 90
#define PIMCOMMONAKONADI_VERSION ((6<<16)|(6<<8)|(90))

#endif
